@@ -1,5 +1,6 @@
 // Copyright (C) 2022 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
+// Qt-Security score:critical reason:data-parser
 
 #include "uniformmodel.h"
 #include "propertyhandler.h"
@@ -432,12 +433,9 @@ bool UniformModel::resetValue(int rowIndex)
 // Updates the image data at rowIndex
 bool UniformModel::setImage(int rowIndex, const QVariant &value)
 {
-    beginResetModel();
     auto &uniform = (*m_uniformTable)[rowIndex];
     uniform.value = value.toString();
 
-    endResetModel();
-
     g_propertyData.insert(uniform.name, value);
 
     emit dataChanged(QAbstractItemModel::createIndex(0, 0),
@@ -936,7 +934,6 @@ void UniformModel::updateCanMoveStatus() {
     if (m_uniformTable->isEmpty())
             return;
     QList<int> usedIds;
-    beginResetModel();
     for (int i = 0; i < m_uniformTable->size() ; i++) {
         auto &uniform = (*m_uniformTable)[i];
         if (usedIds.contains(uniform.nodeId)) {
@@ -956,6 +953,8 @@ void UniformModel::updateCanMoveStatus() {
             usedIds << uniform.nodeId;
         }
     }
-    endResetModel();
+    int lastRowIndex = m_uniformTable->size();
+    emit dataChanged(QAbstractItemModel::createIndex(0, 0),
+                     QAbstractItemModel::createIndex(lastRowIndex, 0));
 }
 
